Tree-style agent path identifier.
AgentPath represents a position in the agent tree, e.g. root/searcher/worker-1.
It is used for routing messages between agents and for event attribution.
With max_agent_depth=1 (the default), paths are always root or root/<child-name>.
Structs
- Agent
Path - A tree-style path identifying an agent in the agent hierarchy.